@@ -15,23 +15,28 @@
 
 """Endpoint action implementations"""
 
-import six
+import logging
 
-from openstackclient.common import command
-from openstackclient.common import utils
-from openstackclient.i18n import _  # noqa
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils
+
+from openstackclient.i18n import _
 from openstackclient.identity import common
 
 
+LOG = logging.getLogger(__name__)
+
+
 class CreateEndpoint(command.ShowOne):
-    """Create new endpoint"""
+    _description = _("Create new endpoint")
 
     def get_parser(self, prog_name):
         parser = super(CreateEndpoint, self).get_parser(prog_name)
         parser.add_argument(
             'service',
             metavar='<service>',
-            help=_('New endpoint service (name or ID)'),
+            help=_('Service to be associated with new endpoint (name or ID)'),
         )
         parser.add_argument(
             '--publicurl',
@@ -64,34 +69,56 @@ class CreateEndpoint(command.ShowOne):
             service.id,
             parsed_args.publicurl,
             parsed_args.adminurl,
-            parsed_args.internalurl,)
+            parsed_args.internalurl,
+        )
 
         info = {}
         info.update(endpoint._info)
         info['service_name'] = service.name
         info['service_type'] = service.type
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
 
 
 class DeleteEndpoint(command.Command):
-    """Delete endpoint"""
+    _description = _("Delete endpoint(s)")
 
     def get_parser(self, prog_name):
         parser = super(DeleteEndpoint, self).get_parser(prog_name)
         parser.add_argument(
-            'endpoint',
+            'endpoints',
             metavar='<endpoint-id>',
-            help=_('Endpoint ID to delete'))
+            nargs='+',
+            help=_('Endpoint(s) to delete (ID only)'),
+        )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        identity_client.endpoints.delete(parsed_args.endpoint)
-        return
+
+        result = 0
+        for endpoint in parsed_args.endpoints:
+            try:
+                identity_client.endpoints.delete(endpoint)
+            except Exception as e:
+                result += 1
+                LOG.error(
+                    _(
+                        "Failed to delete endpoint with "
+                        "ID '%(endpoint)s': %(e)s"
+                    ),
+                    {'endpoint': endpoint, 'e': e},
+                )
+
+        if result > 0:
+            total = len(parsed_args.endpoints)
+            msg = _(
+                "%(result)s of %(total)s endpoints failed " "to delete."
+            ) % {'result': result, 'total': total}
+            raise exceptions.CommandError(msg)
 
 
 class ListEndpoint(command.Lister):
-    """List endpoints"""
+    _description = _("List endpoints")
 
     def get_parser(self, prog_name):
         parser = super(ListEndpoint, self).get_parser(prog_name)
@@ -106,8 +133,15 @@ class ListEndpoint(command.Lister):
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
         if parsed_args.long:
-            columns = ('ID', 'Region', 'Service Name', 'Service Type',
-                       'PublicURL', 'AdminURL', 'InternalURL')
+            columns = (
+                'ID',
+                'Region',
+                'Service Name',
+                'Service Type',
+                'PublicURL',
+                'AdminURL',
+                'InternalURL',
+            )
         else:
             columns = ('ID', 'Region', 'Service Name', 'Service Type')
         data = identity_client.endpoints.list()
@@ -116,22 +150,31 @@ class ListEndpoint(command.Lister):
             service = common.find_service(identity_client, ep.service_id)
             ep.service_name = service.name
             ep.service_type = service.type
-        return (columns,
-                (utils.get_item_properties(
-                    s, columns,
+        return (
+            columns,
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
                     formatters={},
-                ) for s in data))
+                )
+                for s in data
+            ),
+        )
 
 
 class ShowEndpoint(command.ShowOne):
-    """Display endpoint details"""
+    _description = _("Display endpoint details")
 
     def get_parser(self, prog_name):
         parser = super(ShowEndpoint, self).get_parser(prog_name)
         parser.add_argument(
             'endpoint_or_service',
-            metavar='<endpoint-id>',
-            help=_('Endpoint ID to display'),
+            metavar='<endpoint>',
+            help=_(
+                'Endpoint to display (endpoint ID, service ID,'
+                ' service name, service type)'
+            ),
         )
         return parser
 
@@ -144,8 +187,9 @@ class ShowEndpoint(command.ShowOne):
                 match = ep
                 service = common.find_service(identity_client, ep.service_id)
         if match is None:
-            service = common.find_service(identity_client,
-                                          parsed_args.endpoint_or_service)
+            service = common.find_service(
+                identity_client, parsed_args.endpoint_or_service
+            )
             for ep in data:
                 if ep.service_id == service.id:
                     match = ep
@@ -155,4 +199,4 @@ class ShowEndpoint(command.ShowOne):
         info.update(match._info)
         info['service_name'] = service.name
         info['service_type'] = service.type
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
