@@ -36,16 +36,19 @@ def _update_arguments(obj_list, parsed_args_list, option):
         try:
             obj_list.remove(item)
         except ValueError:
-            msg = (_("Subnet does not contain %(option)s %(value)s") %
-                   {'option': option, 'value': item})
+            msg = _("Subnet does not contain %(option)s %(value)s") % {
+                'option': option,
+                'value': item,
+            }
             raise exceptions.CommandError(msg)
 
 
 class AllocationPoolsColumn(cliff_columns.FormattableColumn):
     def human_readable(self):
-        pool_formatted = ['%s-%s' % (pool.get('start', ''),
-                                     pool.get('end', ''))
-                          for pool in self._value]
+        pool_formatted = [
+            '%s-%s' % (pool.get('start', ''), pool.get('end', ''))
+            for pool in self._value
+        ]
         return ','.join(pool_formatted)
 
 
@@ -53,7 +56,8 @@ class HostRoutesColumn(cliff_columns.FormattableColumn):
     def human_readable(self):
         # Map the host route keys to match --host-route option.
         return utils.format_list_of_dicts(
-            convert_entries_to_gateway(self._value))
+            convert_entries_to_gateway(self._value)
+        )
 
 
 _formatters = {
@@ -72,34 +76,42 @@ def _get_common_parse_arguments(parser, is_create=True):
         dest='allocation_pools',
         action=parseractions.MultiKeyValueAction,
         required_keys=['start', 'end'],
-        help=_("Allocation pool IP addresses for this subnet "
-               "e.g.: start=192.168.199.2,end=192.168.199.254 "
-               "(repeat option to add multiple IP addresses)")
+        help=_(
+            "Allocation pool IP addresses for this subnet "
+            "e.g.: start=192.168.199.2,end=192.168.199.254 "
+            "(repeat option to add multiple IP addresses)"
+        ),
     )
     if not is_create:
         parser.add_argument(
             '--no-allocation-pool',
             action='store_true',
-            help=_("Clear associated allocation-pools from the subnet. "
-                   "Specify both --allocation-pool and --no-allocation-pool "
-                   "to overwrite the current allocation pool information.")
+            help=_(
+                "Clear associated allocation-pools from the subnet. "
+                "Specify both --allocation-pool and --no-allocation-pool "
+                "to overwrite the current allocation pool information."
+            ),
         )
     parser.add_argument(
         '--dns-nameserver',
         metavar='<dns-nameserver>',
         action='append',
         dest='dns_nameservers',
-        help=_("DNS server for this subnet "
-               "(repeat option to set multiple DNS servers)")
+        help=_(
+            "DNS server for this subnet "
+            "(repeat option to set multiple DNS servers)"
+        ),
     )
 
     if not is_create:
         parser.add_argument(
             '--no-dns-nameservers',
             action='store_true',
-            help=_("Clear existing information of DNS Nameservers. "
-                   "Specify both --dns-nameserver and --no-dns-nameserver "
-                   "to overwrite the current DNS Nameserver information.")
+            help=_(
+                "Clear existing information of DNS Nameservers. "
+                "Specify both --dns-nameserver and --no-dns-nameserver "
+                "to overwrite the current DNS Nameserver information."
+            ),
         )
     parser.add_argument(
         '--host-route',
@@ -107,29 +119,35 @@ def _get_common_parse_arguments(parser, is_create=True):
         dest='host_routes',
         action=parseractions.MultiKeyValueAction,
         required_keys=['destination', 'gateway'],
-        help=_("Additional route for this subnet "
-               "e.g.: destination=10.10.0.0/16,gateway=192.168.71.254 "
-               "destination: destination subnet (in CIDR notation) "
-               "gateway: nexthop IP address "
-               "(repeat option to add multiple routes)")
+        help=_(
+            "Additional route for this subnet "
+            "e.g.: destination=10.10.0.0/16,gateway=192.168.71.254 "
+            "destination: destination subnet (in CIDR notation) "
+            "gateway: nexthop IP address "
+            "(repeat option to add multiple routes)"
+        ),
     )
     if not is_create:
         parser.add_argument(
             '--no-host-route',
             action='store_true',
-            help=_("Clear associated host-routes from the subnet. "
-                   "Specify both --host-route and --no-host-route "
-                   "to overwrite the current host route information.")
+            help=_(
+                "Clear associated host-routes from the subnet. "
+                "Specify both --host-route and --no-host-route "
+                "to overwrite the current host route information."
+            ),
         )
     parser.add_argument(
         '--service-type',
         metavar='<service-type>',
         action='append',
         dest='service_types',
-        help=_("Service type for this subnet "
-               "e.g.: network:floatingip_agent_gateway. "
-               "Must be a valid device owner value for a network port "
-               "(repeat option to set multiple service types)")
+        help=_(
+            "Service type for this subnet "
+            "e.g.: network:floatingip_agent_gateway. "
+            "Must be a valid device owner value for a network port "
+            "(repeat option to set multiple service types)"
+        ),
     )
 
 
@@ -146,9 +164,7 @@ def _get_columns(item):
         'tenant_id',
     ]
     return utils.get_osc_show_columns_for_sdk_resource(
-        item,
-        column_map,
-        hidden_columns
+        item, column_map, hidden_columns
     )
 
 
@@ -189,11 +205,13 @@ def _get_attrs(client_manager, parsed_args, is_create=True):
                 parsed_args.project_domain,
             ).id
             attrs['project_id'] = project_id
-        attrs['network_id'] = client.find_network(parsed_args.network,
-                                                  ignore_missing=False).id
+        attrs['network_id'] = client.find_network(
+            parsed_args.network, ignore_missing=False
+        ).id
         if parsed_args.subnet_pool is not None:
-            subnet_pool = client.find_subnet_pool(parsed_args.subnet_pool,
-                                                  ignore_missing=False)
+            subnet_pool = client.find_subnet_pool(
+                parsed_args.subnet_pool, ignore_missing=False
+            )
             attrs['subnetpool_id'] = subnet_pool.id
         if parsed_args.use_prefix_delegation:
             attrs['subnetpool_id'] = "prefix_delegation"
@@ -212,21 +230,26 @@ def _get_attrs(client_manager, parsed_args, is_create=True):
 
     if parsed_args.network_segment is not None:
         attrs['segment_id'] = client.find_segment(
-            parsed_args.network_segment, ignore_missing=False).id
+            parsed_args.network_segment, ignore_missing=False
+        ).id
     if 'gateway' in parsed_args and parsed_args.gateway is not None:
         gateway = parsed_args.gateway.lower()
 
         if not is_create and gateway == 'auto':
-            msg = _("Auto option is not available for Subnet Set. "
-                    "Valid options are <ip-address> or none")
+            msg = _(
+                "Auto option is not available for Subnet Set. "
+                "Valid options are <ip-address> or none"
+            )
             raise exceptions.CommandError(msg)
         elif gateway != 'auto':
             if gateway == 'none':
                 attrs['gateway_ip'] = None
             else:
                 attrs['gateway_ip'] = gateway
-    if ('allocation_pools' in parsed_args and
-       parsed_args.allocation_pools is not None):
+    if (
+        'allocation_pools' in parsed_args
+        and parsed_args.allocation_pools is not None
+    ):
         attrs['allocation_pools'] = parsed_args.allocation_pools
     if parsed_args.dhcp:
         attrs['enable_dhcp'] = True
@@ -236,15 +259,20 @@ def _get_attrs(client_manager, parsed_args, is_create=True):
         attrs['dns_publish_fixed_ip'] = True
     if parsed_args.no_dns_publish_fixed_ip:
         attrs['dns_publish_fixed_ip'] = False
-    if ('dns_nameservers' in parsed_args and
-       parsed_args.dns_nameservers is not None):
+    if (
+        'dns_nameservers' in parsed_args
+        and parsed_args.dns_nameservers is not None
+    ):
         attrs['dns_nameservers'] = parsed_args.dns_nameservers
     if 'host_routes' in parsed_args and parsed_args.host_routes is not None:
         # Change 'gateway' entry to 'nexthop' to match the API
         attrs['host_routes'] = convert_entries_to_nexthop(
-            parsed_args.host_routes)
-    if ('service_types' in parsed_args and
-       parsed_args.service_types is not None):
+            parsed_args.host_routes
+        )
+    if (
+        'service_types' in parsed_args
+        and parsed_args.service_types is not None
+    ):
         attrs['service_types'] = parsed_args.service_types
     if parsed_args.description is not None:
         attrs['description'] = parsed_args.description
@@ -259,115 +287,125 @@ class CreateSubnet(command.ShowOne, common.NeutronCommandWithExtraArgs):
     def get_parser(self, prog_name):
         parser = super(CreateSubnet, self).get_parser(prog_name)
         parser.add_argument(
-            'name',
-            metavar='<name>',
-            help=_("New subnet name")
+            'name', metavar='<name>', help=_("New subnet name")
         )
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help=_("Owner's project (name or ID)")
+            help=_("Owner's project (name or ID)"),
         )
         identity_common.add_project_domain_option_to_parser(parser)
         subnet_pool_group = parser.add_mutually_exclusive_group()
         subnet_pool_group.add_argument(
             '--subnet-pool',
             metavar='<subnet-pool>',
-            help=_("Subnet pool from which this subnet will obtain a CIDR "
-                   "(Name or ID)")
+            help=_(
+                "Subnet pool from which this subnet will obtain a CIDR "
+                "(Name or ID)"
+            ),
         )
         subnet_pool_group.add_argument(
             '--use-prefix-delegation',
-            help=_("Use 'prefix-delegation' if IP is IPv6 format "
-                   "and IP would be delegated externally")
+            action='store_true',
+            help=_(
+                "Use 'prefix-delegation' if IP is IPv6 format "
+                "and IP would be delegated externally"
+            ),
         )
         subnet_pool_group.add_argument(
             '--use-default-subnet-pool',
             action='store_true',
-            help=_("Use default subnet pool for --ip-version")
+            help=_("Use default subnet pool for --ip-version"),
         )
         parser.add_argument(
             '--prefix-length',
             metavar='<prefix-length>',
-            help=_("Prefix length for subnet allocation from subnet pool")
+            help=_("Prefix length for subnet allocation from subnet pool"),
         )
         parser.add_argument(
             '--subnet-range',
             metavar='<subnet-range>',
-            help=_("Subnet range in CIDR notation "
-                   "(required if --subnet-pool is not specified, "
-                   "optional otherwise)")
+            help=_(
+                "Subnet range in CIDR notation "
+                "(required if --subnet-pool is not specified, "
+                "optional otherwise)"
+            ),
         )
         dhcp_enable_group = parser.add_mutually_exclusive_group()
         dhcp_enable_group.add_argument(
-            '--dhcp',
-            action='store_true',
-            help=_("Enable DHCP (default)")
+            '--dhcp', action='store_true', help=_("Enable DHCP (default)")
         )
         dhcp_enable_group.add_argument(
-            '--no-dhcp',
-            action='store_true',
-            help=_("Disable DHCP")
+            '--no-dhcp', action='store_true', help=_("Disable DHCP")
         )
         dns_publish_fixed_ip_group = parser.add_mutually_exclusive_group()
         dns_publish_fixed_ip_group.add_argument(
             '--dns-publish-fixed-ip',
             action='store_true',
-            help=_("Enable publishing fixed IPs in DNS")
+            help=_("Enable publishing fixed IPs in DNS"),
         )
         dns_publish_fixed_ip_group.add_argument(
             '--no-dns-publish-fixed-ip',
             action='store_true',
-            help=_("Disable publishing fixed IPs in DNS (default)")
+            help=_("Disable publishing fixed IPs in DNS (default)"),
         )
         parser.add_argument(
             '--gateway',
             metavar='<gateway>',
             default='auto',
-            help=_("Specify a gateway for the subnet.  The three options are: "
-                   "<ip-address>: Specific IP address to use as the gateway, "
-                   "'auto': Gateway address should automatically be chosen "
-                   "from within the subnet itself, 'none': This subnet will "
-                   "not use a gateway, e.g.: --gateway 192.168.9.1, "
-                   "--gateway auto, --gateway none (default is 'auto').")
+            help=_(
+                "Specify a gateway for the subnet.  The three options are: "
+                "<ip-address>: Specific IP address to use as the gateway, "
+                "'auto': Gateway address should automatically be chosen "
+                "from within the subnet itself, 'none': This subnet will "
+                "not use a gateway, e.g.: --gateway 192.168.9.1, "
+                "--gateway auto, --gateway none (default is 'auto')."
+            ),
         )
         parser.add_argument(
             '--ip-version',
             type=int,
             default=4,
             choices=[4, 6],
-            help=_("IP version (default is 4).  Note that when subnet pool is "
-                   "specified, IP version is determined from the subnet pool "
-                   "and this option is ignored.")
+            help=_(
+                "IP version (default is 4).  Note that when subnet pool is "
+                "specified, IP version is determined from the subnet pool "
+                "and this option is ignored."
+            ),
         )
         parser.add_argument(
             '--ipv6-ra-mode',
             choices=['dhcpv6-stateful', 'dhcpv6-stateless', 'slaac'],
-            help=_("IPv6 RA (Router Advertisement) mode, "
-                   "valid modes: [dhcpv6-stateful, dhcpv6-stateless, slaac]")
+            help=_(
+                "IPv6 RA (Router Advertisement) mode, "
+                "valid modes: [dhcpv6-stateful, dhcpv6-stateless, slaac]"
+            ),
         )
         parser.add_argument(
             '--ipv6-address-mode',
             choices=['dhcpv6-stateful', 'dhcpv6-stateless', 'slaac'],
-            help=_("IPv6 address mode, "
-                   "valid modes: [dhcpv6-stateful, dhcpv6-stateless, slaac]")
+            help=_(
+                "IPv6 address mode, "
+                "valid modes: [dhcpv6-stateful, dhcpv6-stateless, slaac]"
+            ),
         )
         parser.add_argument(
             '--network-segment',
             metavar='<network-segment>',
-            help=_("Network segment to associate with this subnet "
-                   "(name or ID)")
+            help=_(
+                "Network segment to associate with this subnet " "(name or ID)"
+            ),
         )
         parser.add_argument(
             '--network',
             required=True,
             metavar='<network>',
-            help=_("Network this subnet belongs to (name or ID)")
+            help=_("Network this subnet belongs to (name or ID)"),
         )
         parser.add_argument(
             '--description',
             metavar='<description>',
-            help=_("Set subnet description")
+            help=_("Set subnet description"),
         )
         _get_common_parse_arguments(parser)
         _tag.add_tag_option_to_parser_for_create(parser, _('subnet'))
@@ -377,7 +415,8 @@ class CreateSubnet(command.ShowOne, common.NeutronCommandWithExtraArgs):
         client = self.app.client_manager.network
         attrs = _get_attrs(self.app.client_manager, parsed_args)
         attrs.update(
-            self._parse_extra_properties(parsed_args.extra_properties))
+            self._parse_extra_properties(parsed_args.extra_properties)
+        )
         obj = client.create_subnet(**attrs)
         # tags cannot be set when created, so tags need to be set later.
         _tag.update_tags_for_set(client, obj, parsed_args)
@@ -395,7 +434,7 @@ class DeleteSubnet(command.Command):
             'subnet',
             metavar="<subnet>",
             nargs='+',
-            help=_("Subnet(s) to delete (name or ID)")
+            help=_("Subnet(s) to delete (name or ID)"),
         )
         return parser
 
@@ -409,14 +448,20 @@ class DeleteSubnet(command.Command):
                 client.delete_subnet(obj)
             except Exception as e:
                 result += 1
-                LOG.error(_("Failed to delete subnet with "
-                          "name or ID '%(subnet)s': %(e)s"),
-                          {'subnet': subnet, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete subnet with "
+                        "name or ID '%(subnet)s': %(e)s"
+                    ),
+                    {'subnet': subnet, 'e': e},
+                )
 
         if result > 0:
             total = len(parsed_args.subnet)
-            msg = (_("%(result)s of %(total)s subnets failed "
-                   "to delete.") % {'result': result, 'total': total})
+            msg = _("%(result)s of %(total)s subnets failed " "to delete.") % {
+                'result': result,
+                'total': total,
+            }
             raise exceptions.CommandError(msg)
 
 
@@ -431,7 +476,7 @@ class ListSubnet(command.Lister):
             '--long',
             action='store_true',
             default=False,
-            help=_("List additional fields in output")
+            help=_("List additional fields in output"),
         )
         parser.add_argument(
             '--ip-version',
@@ -439,65 +484,77 @@ class ListSubnet(command.Lister):
             choices=[4, 6],
             metavar='<ip-version>',
             dest='ip_version',
-            help=_("List only subnets of given IP version in output. "
-                   "Allowed values for IP version are 4 and 6."),
+            help=_(
+                "List only subnets of given IP version in output. "
+                "Allowed values for IP version are 4 and 6."
+            ),
         )
         dhcp_enable_group = parser.add_mutually_exclusive_group()
         dhcp_enable_group.add_argument(
             '--dhcp',
             action='store_true',
-            help=_("List subnets which have DHCP enabled")
+            help=_("List subnets which have DHCP enabled"),
         )
         dhcp_enable_group.add_argument(
             '--no-dhcp',
             action='store_true',
-            help=_("List subnets which have DHCP disabled")
+            help=_("List subnets which have DHCP disabled"),
         )
         parser.add_argument(
             '--service-type',
             metavar='<service-type>',
             action='append',
             dest='service_types',
-            help=_("List only subnets of a given service type in output "
-                   "e.g.: network:floatingip_agent_gateway. "
-                   "Must be a valid device owner value for a network port "
-                   "(repeat option to list multiple service types)")
+            help=_(
+                "List only subnets of a given service type in output "
+                "e.g.: network:floatingip_agent_gateway. "
+                "Must be a valid device owner value for a network port "
+                "(repeat option to list multiple service types)"
+            ),
         )
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help=_("List only subnets which belong to a given project "
-                   "in output (name or ID)")
+            help=_(
+                "List only subnets which belong to a given project "
+                "in output (name or ID)"
+            ),
         )
         identity_common.add_project_domain_option_to_parser(parser)
         parser.add_argument(
             '--network',
             metavar='<network>',
-            help=_("List only subnets which belong to a given network "
-                   "in output (name or ID)")
+            help=_(
+                "List only subnets which belong to a given network "
+                "in output (name or ID)"
+            ),
         )
         parser.add_argument(
             '--gateway',
             metavar='<gateway>',
-            help=_("List only subnets of given gateway IP in output")
+            help=_("List only subnets of given gateway IP in output"),
         )
         parser.add_argument(
             '--name',
             metavar='<name>',
-            help=_("List only subnets of given name in output")
+            help=_("List only subnets of given name in output"),
         )
         parser.add_argument(
             '--subnet-range',
             metavar='<subnet-range>',
-            help=_("List only subnets of given subnet range "
-                   "(in CIDR notation) in output "
-                   "e.g.: --subnet-range 10.10.0.0/16")
+            help=_(
+                "List only subnets of given subnet range "
+                "(in CIDR notation) in output "
+                "e.g.: --subnet-range 10.10.0.0/16"
+            ),
         )
         parser.add_argument(
             '--subnet-pool',
             metavar='<subnet-pool>',
-            help=_("List only subnets which belong to a given subnet pool "
-                   "in output (Name or ID)")
+            help=_(
+                "List only subnets which belong to a given subnet pool "
+                "in output (Name or ID)"
+            ),
         )
         _tag.add_tag_filtering_option_to_parser(parser, _('subnets'))
         return parser
@@ -524,8 +581,9 @@ class ListSubnet(command.Lister):
             ).id
             filters['project_id'] = project_id
         if parsed_args.network:
-            network_id = network_client.find_network(parsed_args.network,
-                                                     ignore_missing=False).id
+            network_id = network_client.find_network(
+                parsed_args.network, ignore_missing=False
+            ).id
             filters['network_id'] = network_id
         if parsed_args.gateway:
             filters['gateway_ip'] = parsed_args.gateway
@@ -535,7 +593,8 @@ class ListSubnet(command.Lister):
             filters['cidr'] = parsed_args.subnet_range
         if parsed_args.subnet_pool:
             subnetpool_id = network_client.find_subnet_pool(
-                parsed_args.subnet_pool, ignore_missing=False).id
+                parsed_args.subnet_pool, ignore_missing=False
+            ).id
             filters['subnetpool_id'] = subnetpool_id
         _tag.get_tag_filtering_args(parsed_args, filters)
         data = network_client.subnets(**filters)
@@ -543,18 +602,40 @@ class ListSubnet(command.Lister):
         headers = ('ID', 'Name', 'Network', 'Subnet')
         columns = ('id', 'name', 'network_id', 'cidr')
         if parsed_args.long:
-            headers += ('Project', 'DHCP', 'Name Servers',
-                        'Allocation Pools', 'Host Routes', 'IP Version',
-                        'Gateway', 'Service Types', 'Tags')
-            columns += ('project_id', 'is_dhcp_enabled', 'dns_nameservers',
-                        'allocation_pools', 'host_routes', 'ip_version',
-                        'gateway_ip', 'service_types', 'tags')
+            headers += (
+                'Project',
+                'DHCP',
+                'Name Servers',
+                'Allocation Pools',
+                'Host Routes',
+                'IP Version',
+                'Gateway',
+                'Service Types',
+                'Tags',
+            )
+            columns += (
+                'project_id',
+                'is_dhcp_enabled',
+                'dns_nameservers',
+                'allocation_pools',
+                'host_routes',
+                'ip_version',
+                'gateway_ip',
+                'service_types',
+                'tags',
+            )
 
-        return (headers,
-                (utils.get_item_properties(
-                    s, columns,
+        return (
+            headers,
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
                     formatters=_formatters,
-                ) for s in data))
+                )
+                for s in data
+            ),
+        )
 
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
@@ -567,56 +648,53 @@ class SetSubnet(common.NeutronCommandWithExtraArgs):
         parser.add_argument(
             'subnet',
             metavar="<subnet>",
-            help=_("Subnet to modify (name or ID)")
+            help=_("Subnet to modify (name or ID)"),
         )
         parser.add_argument(
-            '--name',
-            metavar='<name>',
-            help=_("Updated name of the subnet")
+            '--name', metavar='<name>', help=_("Updated name of the subnet")
         )
         dhcp_enable_group = parser.add_mutually_exclusive_group()
         dhcp_enable_group.add_argument(
-            '--dhcp',
-            action='store_true',
-            default=None,
-            help=_("Enable DHCP")
+            '--dhcp', action='store_true', default=None, help=_("Enable DHCP")
         )
         dhcp_enable_group.add_argument(
-            '--no-dhcp',
-            action='store_true',
-            help=_("Disable DHCP")
+            '--no-dhcp', action='store_true', help=_("Disable DHCP")
         )
         dns_publish_fixed_ip_group = parser.add_mutually_exclusive_group()
         dns_publish_fixed_ip_group.add_argument(
             '--dns-publish-fixed-ip',
             action='store_true',
-            help=_("Enable publishing fixed IPs in DNS")
+            help=_("Enable publishing fixed IPs in DNS"),
         )
         dns_publish_fixed_ip_group.add_argument(
             '--no-dns-publish-fixed-ip',
             action='store_true',
-            help=_("Disable publishing fixed IPs in DNS")
+            help=_("Disable publishing fixed IPs in DNS"),
         )
         parser.add_argument(
             '--gateway',
             metavar='<gateway>',
-            help=_("Specify a gateway for the subnet. The options are: "
-                   "<ip-address>: Specific IP address to use as the gateway, "
-                   "'none': This subnet will not use a gateway, "
-                   "e.g.: --gateway 192.168.9.1, --gateway none.")
+            help=_(
+                "Specify a gateway for the subnet. The options are: "
+                "<ip-address>: Specific IP address to use as the gateway, "
+                "'none': This subnet will not use a gateway, "
+                "e.g.: --gateway 192.168.9.1, --gateway none."
+            ),
         )
         parser.add_argument(
             '--network-segment',
             metavar='<network-segment>',
-            help=_("Network segment to associate with this subnet (name or "
-                   "ID). It is only allowed to set the segment if the current "
-                   "value is `None`, the network must also have only one "
-                   "segment and only one subnet can exist on the network.")
+            help=_(
+                "Network segment to associate with this subnet (name or "
+                "ID). It is only allowed to set the segment if the current "
+                "value is `None`, the network must also have only one "
+                "segment and only one subnet can exist on the network."
+            ),
         )
         parser.add_argument(
             '--description',
             metavar='<description>',
-            help=_("Set subnet description")
+            help=_("Set subnet description"),
         )
         _tag.add_tag_option_to_parser_for_set(parser, _('subnet'))
         _get_common_parse_arguments(parser, is_create=False)
@@ -625,8 +703,9 @@ class SetSubnet(common.NeutronCommandWithExtraArgs):
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
         obj = client.find_subnet(parsed_args.subnet, ignore_missing=False)
-        attrs = _get_attrs(self.app.client_manager, parsed_args,
-                           is_create=False)
+        attrs = _get_attrs(
+            self.app.client_manager, parsed_args, is_create=False
+        )
         if 'dns_nameservers' in attrs:
             if not parsed_args.no_dns_nameservers:
                 attrs['dns_nameservers'] += obj.dns_nameservers
@@ -645,7 +724,8 @@ class SetSubnet(common.NeutronCommandWithExtraArgs):
         if 'service_types' in attrs:
             attrs['service_types'] += obj.service_types
         attrs.update(
-            self._parse_extra_properties(parsed_args.extra_properties))
+            self._parse_extra_properties(parsed_args.extra_properties)
+        )
         if attrs:
             client.update_subnet(obj, **attrs)
         # tags is a subresource and it needs to be updated separately.
@@ -661,13 +741,14 @@ class ShowSubnet(command.ShowOne):
         parser.add_argument(
             'subnet',
             metavar="<subnet>",
-            help=_("Subnet to display (name or ID)")
+            help=_("Subnet to display (name or ID)"),
         )
         return parser
 
     def take_action(self, parsed_args):
-        obj = self.app.client_manager.network.find_subnet(parsed_args.subnet,
-                                                          ignore_missing=False)
+        obj = self.app.client_manager.network.find_subnet(
+            parsed_args.subnet, ignore_missing=False
+        )
         display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
         return (display_columns, data)
@@ -684,22 +765,26 @@ class UnsetSubnet(common.NeutronUnsetCommandWithExtraArgs):
             dest='allocation_pools',
             action=parseractions.MultiKeyValueAction,
             required_keys=['start', 'end'],
-            help=_('Allocation pool IP addresses to be removed from this '
-                   'subnet e.g.: start=192.168.199.2,end=192.168.199.254 '
-                   '(repeat option to unset multiple allocation pools)')
+            help=_(
+                'Allocation pool IP addresses to be removed from this '
+                'subnet e.g.: start=192.168.199.2,end=192.168.199.254 '
+                '(repeat option to unset multiple allocation pools)'
+            ),
         )
         parser.add_argument(
             '--gateway',
             action='store_true',
-            help=_("Remove gateway IP from this subnet")
+            help=_("Remove gateway IP from this subnet"),
         )
         parser.add_argument(
             '--dns-nameserver',
             metavar='<dns-nameserver>',
             action='append',
             dest='dns_nameservers',
-            help=_('DNS server to be removed from this subnet '
-                   '(repeat option to unset multiple DNS servers)')
+            help=_(
+                'DNS server to be removed from this subnet '
+                '(repeat option to unset multiple DNS servers)'
+            ),
         )
         parser.add_argument(
             '--host-route',
@@ -707,27 +792,31 @@ class UnsetSubnet(common.NeutronUnsetCommandWithExtraArgs):
             dest='host_routes',
             action=parseractions.MultiKeyValueAction,
             required_keys=['destination', 'gateway'],
-            help=_('Route to be removed from this subnet '
-                   'e.g.: destination=10.10.0.0/16,gateway=192.168.71.254 '
-                   'destination: destination subnet (in CIDR notation) '
-                   'gateway: nexthop IP address '
-                   '(repeat option to unset multiple host routes)')
+            help=_(
+                'Route to be removed from this subnet '
+                'e.g.: destination=10.10.0.0/16,gateway=192.168.71.254 '
+                'destination: destination subnet (in CIDR notation) '
+                'gateway: nexthop IP address '
+                '(repeat option to unset multiple host routes)'
+            ),
         )
         parser.add_argument(
             '--service-type',
             metavar='<service-type>',
             action='append',
             dest='service_types',
-            help=_('Service type to be removed from this subnet '
-                   'e.g.: network:floatingip_agent_gateway. '
-                   'Must be a valid device owner value for a network port '
-                   '(repeat option to unset multiple service types)')
+            help=_(
+                'Service type to be removed from this subnet '
+                'e.g.: network:floatingip_agent_gateway. '
+                'Must be a valid device owner value for a network port '
+                '(repeat option to unset multiple service types)'
+            ),
         )
         _tag.add_tag_option_to_parser_for_unset(parser, _('subnet'))
         parser.add_argument(
             'subnet',
             metavar="<subnet>",
-            help=_("Subnet to modify (name or ID)")
+            help=_("Subnet to modify (name or ID)"),
         )
         return parser
 
@@ -740,28 +829,36 @@ class UnsetSubnet(common.NeutronUnsetCommandWithExtraArgs):
             attrs['gateway_ip'] = None
         if parsed_args.dns_nameservers:
             attrs['dns_nameservers'] = copy.deepcopy(obj.dns_nameservers)
-            _update_arguments(attrs['dns_nameservers'],
-                              parsed_args.dns_nameservers,
-                              'dns-nameserver')
+            _update_arguments(
+                attrs['dns_nameservers'],
+                parsed_args.dns_nameservers,
+                'dns-nameserver',
+            )
         if parsed_args.host_routes:
             attrs['host_routes'] = copy.deepcopy(obj.host_routes)
             _update_arguments(
                 attrs['host_routes'],
                 convert_entries_to_nexthop(parsed_args.host_routes),
-                'host-route')
+                'host-route',
+            )
         if parsed_args.allocation_pools:
             attrs['allocation_pools'] = copy.deepcopy(obj.allocation_pools)
-            _update_arguments(attrs['allocation_pools'],
-                              parsed_args.allocation_pools,
-                              'allocation-pool')
+            _update_arguments(
+                attrs['allocation_pools'],
+                parsed_args.allocation_pools,
+                'allocation-pool',
+            )
 
         if parsed_args.service_types:
             attrs['service_types'] = copy.deepcopy(obj.service_types)
-            _update_arguments(attrs['service_types'],
-                              parsed_args.service_types,
-                              'service-type')
+            _update_arguments(
+                attrs['service_types'],
+                parsed_args.service_types,
+                'service-type',
+            )
         attrs.update(
-            self._parse_extra_properties(parsed_args.extra_properties))
+            self._parse_extra_properties(parsed_args.extra_properties)
+        )
 
         if attrs:
             client.update_subnet(obj, **attrs)
